==> 0.4.0.tar.gz: example/lib/sort_button.dart <==
import 'package:fc_components/fc_sort_button.dart';
import 'package:fc_components/fc_cell.dart';
import 'package:fc_components/util/adapt.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class SortButton extends StatefulWidget {
  const SortButton({Key? key}) : super(key: key);

  @override
  _SortButtonState createState() => _SortButtonState();
}

class _SortButtonState extends State<SortButton> {
  String cacheSizeStr = '';
  bool canCheckBiometrics = false;
  bool localauthBind = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('FcButton 按钮'),
      ),
      body: ListView(
        children: [
          /// 完整示例
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('完整示例'),
          ),
          // FcCell(
          //   onPressed: () {},
          //   label: const Text('我是 label'),
          //   content: const Text('我是 content'),
          // ),
          // FcSortButton(),
          Row(
            children: [
              FcSortButton(
                text: '正序',
                highlight: true,
                order: FcSortOrder.asc,
                onPressed: (order) {},
              ),
              FcSortButton(
                text: '倒序',
                highlight: true,
                order: FcSortOrder.asc,
                onPressed: (order) {},
              ),
            ],
          ),

          /// content 靠左
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('content 靠左'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
            contentAlignment: Alignment.centerLeft,
          ),

          /// 无 border
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('无 border'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
            border: false,
          ),

          /// 无右侧箭头
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('无右侧箭头'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
            arrow: false,
          ),

          /// 仅 label，无点击态
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('仅 label，无点击态'),
          ),
          const FcCell(
            label: Text('我是 label'),
            arrow: false,
          ),

          /// 长 content
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('长 content'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text(
              '我是 content我是 content我是 content我是 content我是 content我是 content我是 content',
            ),
          ),

          /// 长 content，顶部对齐
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('长 content，顶部对齐'),
          ),
          FcCell(
            onPressed: () {},
            crossAxisAlignment: CrossAxisAlignment.start,
            label: const Text('我是 label'),
            content: const Text(
              '我是 content我是 content我是 content我是 content我是 content我是 content我是 content',
            ),
          ),
        ],
      ),
    );
  }
}

==> 0.5.0.tar.gz: example/lib/sort_button.dart <==
import 'package:fc_components/fc_sort_button.dart';
import 'package:fc_components/util/adapt.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class SortButton extends StatefulWidget {
  const SortButton({Key? key}) : super(key: key);

  @override
  _SortButtonState createState() => _SortButtonState();
}

class _SortButtonState extends State<SortButton> {
  String cacheSizeStr = '';
  bool canCheckBiometrics = false;
  bool localauthBind = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('FcSortButton 排序按钮'),
      ),
      body: ListView(
        children: [
          /// 完整示例
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('完整示例'),
          ),
          Row(
            children: [
              const SizedBox(width: 10),
              FcSortButton(
                text: '正序',
                highlight: true,
                order: FcSortOrder.asc,
                onPressed: (order) {},
              ),
              const SizedBox(width: 10),
              FcSortButton(
                text: '倒序',
                highlight: true,
                order: FcSortOrder.desc,
                onPressed: (order) {},
              ),
            ],
          ),

          /// 单一排序
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('单一排序'),
          ),
          Row(
            children: [
              const SizedBox(width: 10),
              FcSortButton(
                text: '排序',
                highlight: true,
                hasSort: false,
                onPressed: (order) {},
              ),
              const SizedBox(width: 10),
              FcSortButton(
                text: '不排序',
                highlight: false,
                hasSort: false,
                onPressed: (order) {},
              ),
            ],
          ),
        ],
      ),
    );
  }
}
